%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Etnropy      class for LaTeX files              v1.0 1-27-2006 %%
%%                                                                %%
%% \maketitle make the first page automatically                   %%
%%																  %%
%% class style provided by Stefano Mariani						  %%
%% for any information please send an e-mail to:			      %%
%%				   stefano.mariani@polimi.it				      %%
%%																  %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{entropy}[2006/01/27 Entropy paper class]

\DeclareOption{10pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ProcessOptions\relax

\LoadClass[12pt]{article}

\RequirePackage{calc}
\RequirePackage{indentfirst}
\RequirePackage[sort&compress]{natbib}
\RequirePackage{times,fancyhdr}
\RequirePackage{graphicx}
\RequirePackage[dvips]{color}
\definecolor{greens}{rgb}{0,0.502,0.502}

\bibpunct{[}{]}{,}{}{}{}

\renewcommand{\baselinestretch}{1.18} 

%% Title
\renewcommand{\@maketitle}{%
 \thispagestyle{empty}
 \begin{minipage}[t][17mm][t]{0.97\textwidth}
  \begin{flushleft}
  \vspace{-36pt}
  \hspace{-5mm}{\normalfont {\em Entropy}\ {\bfseries \@pubyear}, {\em \@pubvolume}, \@pagerange; DOI: \@doinum}
  \end{flushleft}
  \begin{flushright}
  {{\fontsize{9}{9}\selectfont\bfseries{\colorbox{cyan}{\textcolor{white}{OPEN ACCESS}}}}}\\[8pt]
  {{\fontsize{32}{32}\selectfont\bfseries\itshape \textcolor{greens}{entropy}}}\\
  \normalfont\bfseries ISSN 1099-4300\\[-2pt]
  \normalfont www.mdpi.org/entropy 
  \end{flushright}
 \end{minipage}

 \begin{flushleft}%
 {
 \fontsize{12}{12}\selectfont
 \textit{\@arttype\\}
 \vspace{6pt}
 }
  {%3
   \fontsize{18}{18}\selectfont
   \bfseries{\@title}
   \par
  }%3
  \vspace{12pt}%
  {%4
   \bfseries{\@author}
   \par
  }%4
  \vspace{12pt}%
  {%5
   \@address
   \par
  }%5
  \vspace{17pt}%
  \hrule
  \vspace{6mm} \hspace{5.5mm}
  \begin{tabular}{p{157mm}}
 \noindent\textbf{Abstract:\space}\@abstract \\
  \end{tabular}
 \par
 \vspace{12pt} \hspace{5.5mm}
  \begin{tabular}{p{157mm}}
 \noindent\textbf{Keywords:\space}\@keywords \\
  \end{tabular}
 \par
 \vspace{17pt}
 \hrule
 \vspace{27pt}
}% End of \@maketitle

\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}

\newcommand{\arttype}[1]{\gdef\@arttype{#1}}

\newcommand{\pagerange}[1]{\gdef\@pagerange{#1}}

\newcommand{\doinum}[1]{\gdef\@doinum{#1}}

\newcommand{\pubyear}[1]{\gdef\@pubyear{#1}}

\newcommand{\pubvolume}[1]{\gdef\@pubvolume{#1}}

\newcommand{\address}[1]{\gdef\@address{#1}}

\newcommand{\keywords}[1]{\gdef\@keywords{#1}}

\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}

\renewcommand{\thesection}{\arabic{section}.}
\renewcommand{\section}{ %
  \@startsection{section}{1}{0pt}{12pt}{12pt}{\normalsize\bfseries}}

\renewcommand{\thesubsection}{\arabic{section}.\arabic{subsection}.}
\renewcommand{\subsection}{ %
  \@startsection{subsection}{2}{0pt}{12pt}{12pt}{\normalsize\itshape}}

\renewcommand{\@makecaption}[2]{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\normalsize{\bfseries #1}. #2}%
  \ifdim \wd\@tempboxa >\hsize
    \normalsize{\bfseries #1}. #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}


\setlength{\oddsidemargin}{17.5mm}
\setlength{\voffset}{-1in}
\setlength{\hoffset}{-1in}
\setlength{\topmargin}{18.5mm}
\setlength{\headheight}{0mm}
\setlength{\headsep}{0mm}
\setlength{\textheight}{243.5mm}
\setlength{\textwidth}{175mm}
\setlength{\textfloatsep}{12pt}
\setlength{\abovedisplayskip}{0pt}
\setlength{\belowdisplayskip}{0pt}
\setlength{\parindent}{5mm}
\setlength{\abovecaptionskip}{6pt}
\setlength{\belowcaptionskip}{6pt}
\setlength{\itemsep}{0pt}
\setlength{\partopsep}{0pt}
\setlength{\parsep}{0pt}

\AtBeginDocument{%
  \maketitle
  \thispagestyle{empty}
  \let\maketitle\relax
}

\newcommand{\heading}[1]{\gdef\@heading{#1}}
\setlength{\headsep}{34pt}

\def\ps@myheadings{%
    \def\@oddfoot{}
    \let\@evenfoot\@oddfoot
    \def\@evenhead{%
        {{{\em Entropy} {\bfseries \@pubyear}, {\em \@pubvolume} \hfil {\bfseries \thepage} }
		\vspace{50pt}}}
    \let\@oddhead\@evenhead
    \let\@mkboth\@gobbletwo
    \let\sectionmark\@gobble
    \let\subsectionmark\@gobble
}

\pagestyle{myheadings}

\def\thebibliography#1{\vspace{12pt}
\noindent{{\bfseries References}}\vspace{12pt}%
\list{{\arabic{enumi}}}{\def\makelabel##1{\hss{##1}}\topsep=0\p@\parsep=0\p@
\partopsep=0\p@\itemsep=0\p@
\labelsep=1ex
\itemindent=0\p@
\settowidth\labelwidth{\footnotesize[#1]}%
\leftmargin\labelwidth
\advance\leftmargin\labelsep
%\advance\leftmargin -\itemindent
\usecounter{enumi}}
%\def\newblock{\ }
%\sloppy\clubpenalty4000\widowpenalty4000
%\sfcode`\.=1000\relax
}
\let\endthebibliography=\endlist

\endinput
